Learn R Programming

tsfknn (version 0.5.0)

tsfknn: tsfknn: A package for time series forecasting using KNN regression.

Description

The tsfknn package allows univariate time series forecasting using KNN regression.

Arguments

Functions

knnForecasting

It is used to forecast a time series

n_training_examples

To compute how many training examples would have a model

nearest_neighbors

To see the nearest neighbors used to forecast a times series

predict

To make new forecasts

knn_examples

To see the examples used by the KNN model

rolling_origin

To assess forecasting accuracy using rolling origin evaluation

autoplot

To plot a prediction and the nearest neighbors used in the prediction