The ggplot object representing a plotting with the forecast.
Arguments
forecast
The knnForecast object.
highlight
A string value indicating what elements should be
highlighted. Possible values are "none", "points" and
"neighbors".
faceting
Logical. This applies only if the highlight
parameter is set to "neighbors". It indicates whether the different
nearest neighbors should be seen in different plots (TRUE) or in
one plot.