The tsfknn package allows univariate time series forecasting using KNN regression.
It is used to forecast a time series
To compute how many training examples would have a model
To see the nearest neighbors used to forecast a times series
To make new forecasts
To see the examples used by the KNN model
To assess forecasting accuracy using rolling origin evaluation
To plot a prediction and the nearest neighbors used in the prediction